@@ -274,7 +274,6 @@ class ImagenInformasaunForm(forms.ModelForm):
 
 
 
-
 class KonteuduInformasaunForm(forms.ModelForm):
 	data = forms.DateField(label="Data ",widget=forms.TextInput(attrs={'type': 'date'}))
 	class Meta:
@@ -548,3 +547,101 @@ class ImagenProdutuForm(forms.ModelForm):
 # 	class Meta:
 # 		model = Edisaun
 # 		fields = ['file_pdf']
+
+
+
+
+
+class FileAnunsiuForm(forms.ModelForm):
+	# descriptiond = forms.CharField(label="Observasaun", widget=forms.Textarea(attrs={"rows":2}), required=False)
+
+	class Meta:
+		model = FileAnunsiu
+		fields = ['file_pdf','titulu']
+	def __init__(self, *args, **kwargs):
+		super(FileAnunsiuForm, self).__init__(*args, **kwargs)
+		self.helper = FormHelper()
+		self.helper.form_method = 'post'
+		self.helper.form_id = 'form_anunsiu'
+		self.helper.layout = Layout(
+
+	
+
+		Row(
+			Column('titulu', css_class='form-group col-md-12 mb-0'),
+			Column('file_pdf', css_class='form-group col-md-12 mb-0'),
+			Column(HTML("""<br><button style='float:right;' id = 'bambuinput' class='form-group btn btn-primary' type='submit'> Upload</button>"""), css_class='form-group col-md-12 mb-0'),
+		    css_class='row'),
+
+		)
+
+
+class KonteuduAnunsiuForm(forms.ModelForm):
+	data = forms.DateField(label="Data ",widget=forms.TextInput(attrs={'type': 'date'}))
+	class Meta:
+		model = KonteuduAnunsiu
+		fields = ['titulu','konteudu','data']
+	def __init__(self, *args, **kwargs):
+		super(KonteuduAnunsiuForm, self).__init__(*args, **kwargs)
+		self.helper = FormHelper()
+		self.helper.form_method = 'post'
+		self.helper.form_id = 'form_anunsiu'
+		self.helper.layout = Layout(
+		Row(
+			Column('titulu', css_class='form-group col-md-12 mb-0', onchange="myFunction()"),
+			Column('konteudu', css_class='form-group col-md-12 mb-0'),
+			Column(Field('data', css_class="form-select"), css_class='form-group col-md-12 mb-0'),
+			Column(HTML(""" 
+
+		
+			<br>
+		<div class='float-right'>
+			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
+				</button>
+
+					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>	
+				</div>
+				
+				""")
+	
+		, css_class='form-group col-md-12 mb-0'),
+		    css_class='row'),
+		)
+
+
+
+
+
+
+class KonteuduAnunsiuForm(forms.ModelForm):
+	data = forms.DateField(label="Data ",widget=forms.TextInput(attrs={'type': 'date'}))
+	class Meta:
+		model = KonteuduAnunsiu
+		fields = ['titulu','konteudu','data']
+	def __init__(self, *args, **kwargs):
+		super(KonteuduAnunsiuForm, self).__init__(*args, **kwargs)
+		self.helper = FormHelper()
+		self.helper.form_method = 'post'
+		self.helper.form_id = 'form_informasaun'
+		self.helper.layout = Layout(
+		Row(
+			Column('titulu', css_class='form-group col-md-12 mb-0', onchange="myFunction()"),
+			Column('konteudu', css_class='form-group col-md-12 mb-0'),
+			Column(Field('data', css_class="form-select"), css_class='form-group col-md-12 mb-0'),
+			Column(HTML(""" 
+
+		
+			<br>
+		<div class='float-right'>
+			<button  id = 'bambuinput' class="btn btn-sm btn-info" type="submit"><i class="fa fa-save"></i> {% if asaun  == 'edit' %} Atualiza {% else %} Rejistu {% endif %}
+				</button>
+
+					<a class="btn btn-sm btn-warning" onclick=self.history.back()><span class="btn-label"><i class="fa fa-window-close"></i></span> Kansela</a>	
+				</div>
+				
+				""")
+	
+		, css_class='form-group col-md-12 mb-0'),
+		    css_class='row'),
+		)
+
